==> flink-1.17.2-src.tgz: flink-1.17.2/flink-table/flink-table-planner/src/test/scala/org/apache/flink/table/planner/plan/stream/sql/UnnestTest.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.flink.table.planner.plan.stream.sql

import org.apache.flink.api.scala._
import org.apache.flink.table.api._
import org.apache.flink.table.planner.plan.common.UnnestTestBase
import org.apache.flink.table.planner.utils.TableTestUtil

import org.junit.Test

class UnnestTest extends UnnestTestBase(true) {

  override def getTableTestUtil: TableTestUtil = streamTestUtil()

  @Test
  def testUnnestWithInvalidLookupJoinHint(): Unit = {
    util.addTableSource[(Int, Array[Int])]("T2", 'a, 'b)
    verifyPlan(
      """
        |SELECT /*+ LOOKUP('table'='D', 'retry-predicate'='lookup_miss','retry-strategy'='fixed_delay', 
        |         'fixed-delay'='155 ms', 'max-attempts'='10') */ T2.a
        |FROM T2 CROSS JOIN UNNEST(T2.b) AS D(c)
        |""".stripMargin)
  }
}

==> flink-1.19.3-src.tgz: flink-1.19.3/flink-table/flink-table-planner/src/test/scala/org/apache/flink/table/planner/plan/stream/sql/UnnestTest.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.flink.table.planner.plan.stream.sql

import org.apache.flink.api.scala._
import org.apache.flink.table.api._
import org.apache.flink.table.planner.plan.common.UnnestTestBase
import org.apache.flink.table.planner.utils.TableTestUtil

import org.junit.jupiter.api.Test

class UnnestTest extends UnnestTestBase(true) {

  override def getTableTestUtil: TableTestUtil = streamTestUtil()

  @Test
  def testUnnestWithInvalidLookupJoinHint(): Unit = {
    util.addTableSource[(Int, Array[Int])]("T2", 'a, 'b)
    verifyPlan(
      """
        |SELECT /*+ LOOKUP('table'='D', 'retry-predicate'='lookup_miss','retry-strategy'='fixed_delay', 
        |         'fixed-delay'='155 ms', 'max-attempts'='10') */ T2.a
        |FROM T2 CROSS JOIN UNNEST(T2.b) AS D(c)
        |""".stripMargin)
  }
}
